// File created automatically by custom Dialogger on 5/20/2018, 4:53:22 PM
// Do not tamper with this file.
// It will be replaced automatically by Dialogger and all changes will be lost.
// Instead change IntroMenu.dl.
module DialogueTrees {
	export let IntroMenu = (function () {
        let tree : DialogueTree = new DialogueTree("IntroMenu");
        let node : DialogueNode;
        let choice : DialogueChoice;
        let text : DialogueText;
        let branch : DialogueBranch;
        let set : DialogueSet;
        
        
        node = new DialogueNode("b018bb28-4efc-493b-ac37-31634c4e6406");
        node.setNext("f448e718-9d24-4191-9913-ccc36d97c4c0");
        tree.addStartNode(node);
        
        
        choice = new DialogueChoice("3b8c8bcb-0ac8-40dc-9f62-4abbde0d0f7f");
        choice.setSay(() => { return new Say("Start Game");});
        choice.setNext("719e71dd-9989-4015-93af-9fb7096002c1");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("53710087-4002-41b7-b089-cadabedbcafd");
        choice.setSay(() => { return new Say("Load from file");});
        choice.setNext("f25f6525-dad6-45d7-a391-246c1b02b569");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("b4593a36-ca83-4afc-b01b-e71344ca6e1f");
        choice.setSay(() => { return new Say("Settings");});
        choice.setNext("d4a379b5-06c9-4fca-a25c-b1a31b6bf93d");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("4c5032a5-5509-4a00-b8c7-788e7ddbf17d");
        choice.setSay(() => { return new Say("About");});
        choice.setNext("6b3f385b-8283-4635-9c73-e2303d77642d");
        tree.addNode(choice);
        
        
        node = new DialogueNode("674841a6-3752-4c81-977d-19e111536203");
        node.setName("2");
        node.setChoices(["3b8c8bcb-0ac8-40dc-9f62-4abbde0d0f7f","53710087-4002-41b7-b089-cadabedbcafd","4c5032a5-5509-4a00-b8c7-788e7ddbf17d","b4593a36-ca83-4afc-b01b-e71344ca6e1f","a55f46fa-98a9-4dff-9f1c-4f88c18ce8dd"]);
        tree.addNode(node);
        
        
        text = new DialogueText("bc32e411-3c54-4747-ad79-506fc5a9d6c9");
        text.setSay(() => { return new Say(Say.CENTERED, new SayImage("introLogo"), Say.LINE_BREAK, new SayItalic("The Obelisk is an adult interactive fiction game set in a post-apocalyptic world ravaged by a magical structure."));});
        text.setNext("36da9ea6-909c-4c0c-94d1-a17fef44452d");
        tree.addNode(text);
        
        
        text = new DialogueText("36da9ea6-909c-4c0c-94d1-a17fef44452d");
        text.setSay(() => { return new Say("A sleek, black obelisk appeared, monsters pouring from it, threatening the world. Many tried to reach the obelisk, only to return changed - monstrous. Civilization was unable to cope with the creatures and humanity soon returned to its old, tribal ways, humans becoming rarer with each passing day. Centuries have passed and technology is now scarce, with people leading simpler lives in small settlements.",                     Say.PARAGRAPH_BREAK,                     "You were born in the ashes of the old world, living in isolation as you and your fellow men attempt to stay safe from the evils of The Obelisk. ",                     Say.PARAGRAPH_BREAK,                     "Now, fate has decided you must go, reach The Obelisk and destroy it. Will you succeed in stopping it, or will you lose yourself to all the changes it will bring to you?");});
        text.setNext("674841a6-3752-4c81-977d-19e111536203");
        tree.addNode(text);
        
        
        node = new DialogueNode("9f11871f-eebd-4b9a-b3db-ed9be8cf78e7");
        node.setName("1");
        node.setNext("9eeb2100-917d-41fd-b756-6d3b80e92463");
        tree.addNode(node);
        
        
        branch = new DialogueBranch("5d1dfb86-abd9-4ad6-bf07-8ced5476e401");
        branch.setVariable(() => { return PlayBegins.LOAD_FAILED;});
        branch.addBranch("415dc32a-1549-429d-9ac4-8cd1b4c92c14", () => { return true;});
        branch.setNext("f82fc177-b4bd-4f06-b7ab-216259e056a5");
        tree.addNode(branch);
        
        
        set = new DialogueSet("f82fc177-b4bd-4f06-b7ab-216259e056a5");
        set.setFunction(() => {Elements.endMenu();});
        tree.addNode(set);
        
        
        set = new DialogueSet("9eeb2100-917d-41fd-b756-6d3b80e92463");
        set.setFunction(() => {Elements.clearMainScreen();});
        set.setNext("bc32e411-3c54-4747-ad79-506fc5a9d6c9");
        tree.addNode(set);
        
        
        node = new DialogueNode("415dc32a-1549-429d-9ac4-8cd1b4c92c14");
        node.setNext("1");
        tree.addNode(node);
        
        
        set = new DialogueSet("f448e718-9d24-4191-9913-ccc36d97c4c0");
        set.setFunction(() => {Elements.startMenu(); tree.setRepeatChoices(false);});
        set.setNext("9f11871f-eebd-4b9a-b3db-ed9be8cf78e7");
        tree.addNode(set);
        
        
        choice = new DialogueChoice("ef9253b9-5c24-46cc-8e2d-5562a1544f07");
        choice.setSay(() => { return new Say(SaveHandler.getSayForSlot(0));});
        choice.setNext("9594cf06-6062-4952-b378-6aedaafe2951");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("82c512c6-0115-4d72-a413-5728a623f04b");
        choice.setSay(() => { return new Say(SaveHandler.getSayForSlot(1));});
        choice.setNext("fe95cfb3-b9f5-4b12-83aa-94d26e5bcac0");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("7315835a-4d95-4377-828c-8a4ca7e49f87");
        choice.setSay(() => { return new Say(SaveHandler.getSayForSlot(2));});
        choice.setNext("dc884974-7bb2-436f-b3a4-cdf8550bd494");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("50afd6f8-87ce-49bf-b689-4819bc5dc8e7");
        choice.setSay(() => { return new Say(SaveHandler.getSayForSlot(3));});
        choice.setNext("62f5ea88-c6f0-4469-87f2-ea3b37638509");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("d79e9955-f81e-4ac9-8246-a02b0bd49dae");
        choice.setSay(() => { return new Say(SaveHandler.getSayForSlot(4));});
        choice.setNext("ee4ecd8b-59e2-43a6-8150-8a835d6eeae1");
        tree.addNode(choice);
        
        
        node = new DialogueNode("719e71dd-9989-4015-93af-9fb7096002c1");
        node.setName("SlotChoices");
        node.setChoices(["ef9253b9-5c24-46cc-8e2d-5562a1544f07","82c512c6-0115-4d72-a413-5728a623f04b","7315835a-4d95-4377-828c-8a4ca7e49f87","50afd6f8-87ce-49bf-b689-4819bc5dc8e7","d79e9955-f81e-4ac9-8246-a02b0bd49dae","9483a087-04d0-48dd-884f-946930771b95","defe0f4c-4452-40f3-aff1-ba076263fcbc"]);
        tree.addNode(node);
        
        
        set = new DialogueSet("9594cf06-6062-4952-b378-6aedaafe2951");
        set.setFunction(() => {SaveHandler.setSlot(0);});
        set.setNext("a6b6b3d2-25ef-41b1-a5b5-25143f1b41f9");
        tree.addNode(set);
        
        
        set = new DialogueSet("fe95cfb3-b9f5-4b12-83aa-94d26e5bcac0");
        set.setFunction(() => {SaveHandler.setSlot(1);});
        set.setNext("a6b6b3d2-25ef-41b1-a5b5-25143f1b41f9");
        tree.addNode(set);
        
        
        set = new DialogueSet("dc884974-7bb2-436f-b3a4-cdf8550bd494");
        set.setFunction(() => {SaveHandler.setSlot(2);});
        set.setNext("a6b6b3d2-25ef-41b1-a5b5-25143f1b41f9");
        tree.addNode(set);
        
        
        set = new DialogueSet("62f5ea88-c6f0-4469-87f2-ea3b37638509");
        set.setFunction(() => {SaveHandler.setSlot(3);});
        set.setNext("a6b6b3d2-25ef-41b1-a5b5-25143f1b41f9");
        tree.addNode(set);
        
        
        set = new DialogueSet("ee4ecd8b-59e2-43a6-8150-8a835d6eeae1");
        set.setFunction(() => {SaveHandler.setSlot(4);});
        set.setNext("a6b6b3d2-25ef-41b1-a5b5-25143f1b41f9");
        tree.addNode(set);
        
        
        set = new DialogueSet("f25f6525-dad6-45d7-a391-246c1b02b569");
        set.setFunction(() => {return SaveHandler.loadFromFile();});
        set.setNext("5d1dfb86-abd9-4ad6-bf07-8ced5476e401");
        tree.addNode(set);
        
        
        choice = new DialogueChoice("9483a087-04d0-48dd-884f-946930771b95");
        choice.setSay(() => { return new Say("Erase a save");});
        choice.setConditions(() => { return !SaveHandler.isErasing();});
        choice.setNext("ee65c84a-021f-44d3-aa34-50235f438c96");
        tree.addNode(choice);
        
        
        choice = new DialogueChoice("defe0f4c-4452-40f3-aff1-ba076263fcbc");
        choice.setSay(() => { return new Say("Don't erase my saves!");});
        choice.setConditions(() => { return SaveHandler.isErasing();});
        choice.setNext("ee65c84a-021f-44d3-aa34-50235f438c96");
        tree.addNode(choice);
        
        
        set = new DialogueSet("ee65c84a-021f-44d3-aa34-50235f438c96");
        set.setFunction(() => {SaveHandler.toggleErasing()});
        set.setNext("6f15f7d6-4944-4b93-9d47-7046e8ae1f15");
        tree.addNode(set);
        
        
        node = new DialogueNode("6f15f7d6-4944-4b93-9d47-7046e8ae1f15");
        node.setNext("SlotChoices");
        tree.addNode(node);
        
        
        set = new DialogueSet("915492f1-8fa7-4ddc-9dc0-6b0340f738c8");
        set.setFunction(() => {return SaveHandler.loadFromStorage();});
        set.setNext("f82fc177-b4bd-4f06-b7ab-216259e056a5");
        tree.addNode(set);
        
        
        node = new DialogueNode("d4a379b5-06c9-4fca-a25c-b1a31b6bf93d");
        node.setNext("Settings");
        tree.addNode(node);
        
        
        node = new DialogueNode("6b3f385b-8283-4635-9c73-e2303d77642d");
        node.setNext("About");
        tree.addNode(node);
        
        
        node = new DialogueNode("b75c038c-654c-4c62-8f49-2f4518f52cff");
        node.setName("Settings");
        node.setNext("d33456b8-72b6-4214-90b3-3eba2442b287");
        tree.addNode(node);
        
        
        text = new DialogueText("d33456b8-72b6-4214-90b3-3eba2442b287");
        text.setSay(() => { return new Say("Not implemented.");});
        text.setNext("bc24b446-d6a2-4284-93fb-67ad3598fcd1");
        tree.addNode(text);
        
        
        set = new DialogueSet("bc24b446-d6a2-4284-93fb-67ad3598fcd1");
        set.setFunction(() => {return Elements.waitForAnyKey();});
        set.setNext("81f9d62b-907e-48ae-84fe-78c7cecc4fe3");
        tree.addNode(set);
        
        
        node = new DialogueNode("81f9d62b-907e-48ae-84fe-78c7cecc4fe3");
        node.setNext("1");
        tree.addNode(node);
        
        
        node = new DialogueNode("c342e112-5c73-4c82-8882-47ca3a71c914");
        node.setName("About");
        node.setNext("d33456b8-72b6-4214-90b3-3eba2442b287");
        tree.addNode(node);
        
        
        choice = new DialogueChoice("a55f46fa-98a9-4dff-9f1c-4f88c18ce8dd");
        choice.setSay(() => { return new Say("Note about content (Spoiler Alert)");});
        choice.setNext("7c2060aa-66ce-4dbb-88d2-0c8f190e0a6c");
        tree.addNode(choice);
        
        
        text = new DialogueText("59a3cb30-d4ba-4b46-8157-b900fc7022dd");
        text.setSay(() => { return new Say(Say.CENTERED, new SayImage("introLogo"), Say.LINE_BREAK, new SayItalic("The Obelisk is an adult interactive fiction game set in a post-apocalyptic world ravaged by a magical structure."));});
        text.setNext("1b8bdc9d-a4bf-40aa-a382-f7813c158840");
        tree.addNode(text);
        
        
        set = new DialogueSet("c27829b7-7199-4b1e-9334-536258546cfc");
        set.setFunction(() => {return Elements.waitForAnyKey();});
        set.setNext("42401145-9154-40c3-a9d3-4f83df97b89e");
        tree.addNode(set);
        
        
        node = new DialogueNode("42401145-9154-40c3-a9d3-4f83df97b89e");
        node.setNext("1");
        tree.addNode(node);
        
        
        set = new DialogueSet("7c2060aa-66ce-4dbb-88d2-0c8f190e0a6c");
        set.setFunction(() => {Elements.clearMainScreen();});
        set.setNext("59a3cb30-d4ba-4b46-8157-b900fc7022dd");
        tree.addNode(set);
        
        
        text = new DialogueText("1b8bdc9d-a4bf-40aa-a382-f7813c158840");
        text.setSay(() => { return new Say("In this story, the Obelisk will attempt to give the player exactly what the player wants, but that's not always what the player thinks they want. This is a pornographic game first and a roleplaying game second, which means that it is assumed that the player character wants sex - even if they don't act like it.", Say.PARAGRAPH_BREAK, "Therefore, this game will \"fit\" for players who go in with that mentality, but it ", new SayBold("will"), " look differently for players with a different point of view for their characters. While roleplaying is encouraged, that is not how the game was written, so if you're playing it that way, it's just your choice.", Say.PARAGRAPH_BREAK, "There is no sex without explicit consent from the NPCs: implicit consent is only used for the player character, because that's part of the story. It is possible to remove the player's consent, thereby having no unwanted sex scenes occur, by setting up the content options, which will disable content without explicit consent (i.e. disabling M/M Sex Scenes means this kind of thing will only happen if you actively ask an NPC for it).", Say.PARAGRAPH_BREAK, "While the content options are there to tailor your experience, the game is made with \"all content is available\" in mind, which might result in a playthrough that's not much fun if you disable too many things. Still, that's your choice. Game on.");});
        text.setNext("c27829b7-7199-4b1e-9334-536258546cfc");
        tree.addNode(text);
        
        
        branch = new DialogueBranch("a6b6b3d2-25ef-41b1-a5b5-25143f1b41f9");
        branch.setVariable(() => { return SaveHandler.isVirgin();});
        branch.addBranch("d0dcd7c6-26ae-41d0-99a6-e0cae17ae381", () => { return true;});
        branch.setNext("915492f1-8fa7-4ddc-9dc0-6b0340f738c8");
        tree.addNode(branch);
        
        
        text = new DialogueText("b8ee6702-8d38-4bd7-9b24-df8c901a50d4");
        text.setSay(() => { return new Say(new SayBold("A note on saves: "), "The selected slot will be saved to browser storage, so it will be deleted if the browser ever decides to delete it. The game will write to that save slot every turn, so you don't need to worry about that. Alternatively, you can manually save in-game, which will save to a file.");});
        text.setNext("50876e13-23b9-43c0-b6b1-a89b1683d5e7");
        tree.addNode(text);
        
        
        set = new DialogueSet("50876e13-23b9-43c0-b6b1-a89b1683d5e7");
        set.setFunction(() => {return Elements.waitForAnyKey();});
        set.setNext("915492f1-8fa7-4ddc-9dc0-6b0340f738c8");
        tree.addNode(set);
        
        
        set = new DialogueSet("d0dcd7c6-26ae-41d0-99a6-e0cae17ae381");
        set.setFunction(() => {Elements.clearMainScreen();});
        set.setNext("b8ee6702-8d38-4bd7-9b24-df8c901a50d4");
        tree.addNode(set);
        
        return tree;
    })();
}